.. _ydoc directive_3 directive_3_2 d322 d322a:

``d322a``
=========

D 3.2.2a executes a series of flips

Single-valued parameters:

  * ``nflips``: Number of flips (default: 0)

  * ``flipaxis``: Axis around which flip is performed



----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.